# django-ajax-feedback
Django easy ajax feedback form

Installation
------------
#. Install or add ``django-ajaxfeedback`` to your Python path.
#. Add ``django-ajaxfeedback`` to your ``INSTALLED_APPS`` setting.
#. Add a ``AJAX_FEEDBACK_RECIPIENT_LIST`` setting to the project's ``settings.py`` file.
    AJAX_FEEDBACK_RECIPIENT_LIST = ('user@example.com')